BinaryNaNPropagationMode

Enum BinaryNaNPropagationMode 

#[repr(u8)]
pub enum BinaryNaNPropagationMode { AlwaysCanonical = 0, FirstSecond = 1, SecondFirst = 2, FirstSecondPreferringSNaN = 3, SecondFirstPreferringSNaN = 4, }
Select how NaN payloads should be propagated

Variants



AlwaysCanonical = 0

NaN payloads are always canonical



FirstSecond = 1

If the first argument is a NaN, then the result uses the first argument’s payload, else if the second argument is a NaN, then the result uses the second argument’s payload, else the result is the canonical NaN.



SecondFirst = 2

If the second argument is a NaN, then the result uses the second argument’s payload, else if the first argument is a NaN, then the result uses the first argument’s payload, else the result is the canonical NaN.



FirstSecondPreferringSNaN = 3

If the first argument is a signaling NaN, then the result uses the first argument’s payload, else if the second argument is a signaling NaN, then the result uses the second argument’s payload, else if the first argument is a NaN, then the result uses the first argument’s payload, else if the second argument is a NaN, then the result uses the second argument’s payload, else the result is the canonical NaN.



SecondFirstPreferringSNaN = 4

If the second argument is a signaling NaN, then the result uses the second argument’s payload, else if the first argument is a signaling NaN, then the result uses the first argument’s payload, else if the second argument is a NaN, then the result uses the second argument’s payload, else if the first argument is a NaN, then the result uses the first argument’s payload, else the result is the canonical NaN.

Implementations

Source

impl BinaryNaNPropagationMode

pub fn calculate_propagation_results( self, first_class: FloatClass, second_class: FloatClass, ) -> BinaryNaNPropagationResults

calculate the result of NaN propagation for a floating-point operation