QuietNaNFormat

Enum QuietNaNFormat 

#[repr(u8)]
pub enum QuietNaNFormat { Standard = 0, MIPSLegacy = 1, }
the format for quiet NaN values

IEEE 754 states that implementations should use the MSB of the mantissa being set to indicate a quiet NaN, however MIPS before the 2008 revision and PA-RISC use the MSB of the mantissa being clear to indicate a quiet NaN.

Variants



Standard = 0

MSB of mantissa set to indicate quiet NaN



MIPSLegacy = 1

MSB of mantissa clear to indicate quiet NaN; also used in PA-RISC

Implementations

Source

impl QuietNaNFormat

pub fn is_nan_quiet(self, mantissa_msb_set: bool) -> bool

returns true if a NaN with the mantissa MSB set to mantissa_msb_set is a quiet NaN