FloatTraits

Trait FloatTraits 

pub trait FloatTraits:
    Clone
    + Debug
    + PartialEq {
    type Bits: FloatBitsType;

    // Required method
    fn properties(&self) -> FloatProperties;
}
FloatProperties values along with the type used to represent bits for a floating-point format

Required Associated Types

type Bits: FloatBitsType

the type used to represent bits for a floating-point format

Required Methods

fn properties(&self) -> FloatProperties

get the FloatProperties value

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors